import React from 'react';
import Taro from '@tarojs/taro';
import { Block } from '@tarojs/components';
import { CellGroup, Cell } from '@antmjs/vantui';
import Page from '@/layouts/index';
import { ROLE_INSPECTOR, ROLE_MANAGER } from '@/utils/user';
import { getTaIssueById } from '@/services/taissue';
import IssueForm from '../components/Issue';
import Save from './components/Save';
import Edit from './components/Edit';
import Assigned from './components/Assigned';

export default (props) => {

  const router = Taro.useRouter();
  const { id, act } = router.params;

  const [loading, setLoading] = React.useState(false);
  const [issue, setIssue] = React.useState();

  React.useEffect(() => {
    if (id) {
      setLoading(true)
      getTaIssueById(id).then(res => {
        setLoading(false);
        setIssue(res);
      }).catch(() => {
        setLoading(false);
      });
    }
  }, [id]);

  return (
    <Page roles={[ROLE_INSPECTOR, ROLE_MANAGER]} loading={loading}>
      <IssueForm
        issue={issue}
        readOnly={id&&!act}
        showOrg={act === 'assigned'}
        showExpireDate={act === 'assigned'}
        renderAction={(formData) => (
          <Block>
            {!id && <Save formData={formData} />}
            {act === 'edit' && <Edit issue={issue} formData={formData} />}
            {act === 'assigned' && <Assigned issue={issue} formData={formData} />}
          </Block>
        )}
      />
    </Page>
  )
}
