import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Tab, Tabs } from '@antmjs/vantui';
import Page from '@/layouts/index';
import PowerList from '@/components/PowerList';
import Card from '@/components/IssueCard';
import { getTaIssue } from '@/services/taissue';
import { ROLE_INSPECTOR, ROLE_MANAGER } from '@/utils/user';
import { useModel } from '@/store';
import { getIssueStatus } from '@/utils/biz';

// 只有督察员能看到当前页面
export default (props) => {
  const { user } = useModel('user');

  const onClick = (item) => {

    let act = '';
    const status = getIssueStatus(item);
    
    // 如果是管理员
    if (user.dutyList.indexOf(ROLE_MANAGER) > -1) {
      // 如果是待交办
      if (status.value === 0) {
        act = 'assigned';
      }
    } else if (user.dutyList.indexOf(ROLE_INSPECTOR) > -1) {
      // 如果是待交办
      if (status.value === 0) {
        act = 'edit';
      }
    }

    Taro.navigateTo({
      url: `/pages/issue/edit/index?id=${item.issueId}&act=${act}`
    })
  }
  
  return (
    <Page>
      <Tabs sticky>
        <Tab title="全部">
          <PowerList
            request={getTaIssue}
            params={{mine: true}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="未交办">
          <PowerList
            request={getTaIssue}
            params={{bizStatus: 'start', mine: true}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="已交办">
          <PowerList
            request={getTaIssue}
            params={{bizStatus: 'start', mine: true}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="已办结">
          <PowerList
            request={getTaIssue}
            params={{bizStatus: 'end', mine: true}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="已逾期">
          <PowerList
            request={getTaIssue}
            params={{bizStatus: 'expired', mine: true}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="已打回">
          <PowerList
            request={getTaIssue}
            params={{bizStatus: 'reject', mine: true}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
      </Tabs>
    </Page>
  )
}
