import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Cell, CellGroup, Field, Button } from '@antmjs/vantui';
import DatePicker from '@/components/DatePicker';
import { getDateStr } from '@/utils/date';
import { postTaIssueApply } from '@/services/taissueapply';
import { warn } from '@/utils/message';

const today = new Date();
export default (props) => {

  const { orgIssue } = props;

  const [loading, setLoading] = React.useState(false);
  const [formData, setFormData] = React.useState({});
  const [showDatePicker, setShowDatePicker] = React.useState(false);

  const setFieldValue = (key, value) => {
    setFormData({
      ...formData,
      [key]: value,
    })
  }
  
  const onDateChange = (dt) => {
    const date = getDateStr(dt);
    setFieldValue('content', date);
    setShowDatePicker(false);
  }

  const onSubmit = () => {
    try {
      warn(!formData.content, '请选择延期时间');
      warn(!formData.remark, '请填写延期理由');
    } catch (e) {
      return ;
    }

    const data = {
      issueId: orgIssue.issueId,
      applyType: 'delay',
      ...formData
    }

    setLoading(true);
    postTaIssueApply(data).then(() => {
      Taro.navigateBack({delta: 1});
      setLoading(false);
    }).catch(() => {
      setLoading(false);
    })
  }
  
  return (
    <>
      <DatePicker
        type="date"
        minDate={today}
        show={showDatePicker}
        value={formData.content}
        onCancel={() => setShowDatePicker(false)}
        onChange={onDateChange}
      />
      <CellGroup style={{marginTop: '20px'}}>
        <Cell
          isLink
          title="延期时间"
          value={formData.content}
          onClick={() => setShowDatePicker(true)}
        />
        <Cell title="延期理由" />
        <Field
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={formData.remark}
          onChange={e => setFieldValue('remark', e.detail)}
        />
      </CellGroup>
      <View style={{marginTop: '20px', padding: 'var(--main-space)'}}>
        <Button block type="primary" onClick={onSubmit}>申请延期</Button>
      </View>
    </>
  )
}
