import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Cell, CellGroup, Field, Button } from '@antmjs/vantui';
import Page from '@/layouts/index';
import Uploader from '@/components/Uploader/index';
import { getTaIssueById } from '@/services/taissue';
import { getTaOrgIssueByIssueId } from '@/services/taorgissue';

import IssueInfo from '../../components/issue-info';
import Verify from './components/Verify';
import ExpireApply from './components/ExpireApply';
import IssueEnd from './components/IssueEnd';

export default (props) => {

  const router = Taro.useRouter();
  const { id, act } = router.params;

  const [loading, setLoading] = React.useState(false);
  const [issue, setIssue] = React.useState();
  const [orgIssue, setOrgIssue] = React.useState();

  const setFormData = (key, value) => {
    setOrgIssue({
      ...(orgIssue || {}),
      [key]: value,
    })
  }

  React.useEffect(() => {
    if (id) {
      setLoading(true)
      getTaIssueById(id).then(res => {
        setLoading(false);
        setIssue(res);
      }).catch(() => {
        setLoading(false);
      });

      getTaOrgIssueByIssueId(id).then(res => setOrgIssue(res));
    }
  }, [id]);
  
  return (
    <Page loading={loading}>
      <IssueInfo issue={issue} />
      {
        act == 'verify' && <Verify orgIssue={orgIssue} />
      }
      {
        act == 'delay' && <ExpireApply orgIssue={orgIssue} />
      }
      {
        act == 'end' && <IssueEnd orgIssue={orgIssue} />
      }
    </Page>
  )
}
